@@ -8,6 +8,7 @@ use std::env;
 use std::fmt;
 use std::path::Path;
 use std::path::PathBuf;
+use std::process::Command;
 use std::str;
 use target_lexicon::{Architecture, Environment, Triple};
 use tracing::error;
@@ -30,6 +31,7 @@ pub enum Os {
     Haiku,
     Emscripten,
     Wasi,
+    Aix,
 }
 
 impl fmt::Display for Os {
@@ -47,6 +49,7 @@ impl fmt::Display for Os {
             Os::Haiku => write!(f, "Haiku"),
             Os::Emscripten => write!(f, "Emscripten"),
             Os::Wasi => write!(f, "Wasi"),
+            Os::Aix => write!(f, "AIX"),
         }
     }
 }
@@ -184,6 +187,7 @@ fn get_supported_architectures(os: &Os) -> Vec<Arch> {
         Os::Haiku => vec![Arch::X86_64],
         Os::Solaris => vec![Arch::X86_64, Arch::Sparc64],
         Os::Emscripten | Os::Wasi => vec![Arch::Wasm32],
+        Os::Aix => vec![Arch::Powerpc64],
     }
 }
 
@@ -243,7 +247,8 @@ impl Target {
             OperatingSystem::Illumos => Os::Illumos,
             OperatingSystem::Haiku => Os::Haiku,
             OperatingSystem::Emscripten => Os::Emscripten,
-            OperatingSystem::Wasi => Os::Wasi,
+            OperatingSystem::Wasi | OperatingSystem::WasiP1 | OperatingSystem::WasiP2 => Os::Wasi,
+            OperatingSystem::Aix => Os::Aix,
             unsupported => bail!("The operating system {:?} is not supported", unsupported),
         };
 
@@ -375,6 +380,7 @@ impl Target {
             Os::Emscripten => "emscripten",
             // This isn't real, there's no sys.platform here
             Os::Wasi => "wasi",
+            Os::Aix => "aix",
         }
     }
 
@@ -457,7 +463,8 @@ impl Target {
             | Os::Illumos
             | Os::Haiku
             | Os::Emscripten
-            | Os::Wasi => true,
+            | Os::Wasi
+            | Os::Aix => true,
         }
     }
 
@@ -612,3 +619,24 @@ fn rustc_version_meta() -> Result<VersionMeta> {
     })?;
     Ok(meta)
 }
+
+pub(crate) fn detect_arch_from_python(python: &PathBuf, target: &Target) -> Option<String> {
+    match Command::new(python)
+        .arg("-c")
+        .arg("import sysconfig; print(sysconfig.get_platform(), end='')")
+        .output()
+    {
+        Ok(output) if output.status.success() => {
+            let platform = String::from_utf8_lossy(&output.stdout);
+            if platform.contains("macos") {
+                if platform.contains("x86_64") && target.target_arch() != Arch::X86_64 {
+                    return Some("x86_64-apple-darwin".to_string());
+                } else if platform.contains("arm64") && target.target_arch() != Arch::Aarch64 {
+                    return Some("aarch64-apple-darwin".to_string());
+                }
+            }
+        }
+        _ => eprintln!("⚠️  Warning: Failed to determine python platform"),
+    }
+    None
+}
